File

Enum File 

#[repr(u8)]
pub enum File { A = 0, B = 1, C = 2, D = 3, E = 4, F = 5, G = 6, H = 7, }
A file of the chessboard.

Variants



A = 0



B = 1



C = 2



D = 3



E = 4



F = 5



G = 6



H = 7

Implementations

Source

impl File

pub const ALL: [File; 8]

A, …, H.

pub const fn new(index: u32) -> File

Gets a File from an integer index.

Panics

Panics if the index is not in the range 0..=7.

pub const unsafe fn new_unchecked(index: u32) -> File

Gets a File from an integer index.

Safety

It is the callers responsibility to ensure the index is in the range 0..=7.

pub const fn from_char(ch: char) -> Option<File>

pub const fn char(self) -> char

pub const fn upper_char(self) -> char

pub fn offset(self, delta: i32) -> Option<File>

pub const fn distance(self, other: File) -> u32

pub const fn flip_horizontal(self) -> File

pub const fn flip_diagonal(self) -> Rank

pub const fn flip_anti_diagonal(self) -> Rank

pub const fn to_u32(self) -> u32

pub const fn to_usize(self) -> usize